# SID Analyzer

## Description

This script analyzes Microsoft SID.

## Requirements

 - python3
 - Python 3 Standard library

## Installation

```bash
pip install SIDAnalyzer
```

## Usages

```
~# python3 SIDAnalyzer.py S-1-5-21-5846521589-7854895235-4517625475-500
~# echo S-1-5-21-5846521589-7854895235-4517625475-500 | python3 SIDAnalyzer.py
~# python3 SIDAnalyzer.py S-1-5-21-5846521589-7854895235-4517625475-500 S-1-5-21-5846521589-7854895235-4517625475-501
~# python3 SIDAnalyzer.py
S-1-5-21-5846521589-7854895235-4517625475-500
S-1-5-21-5846521589-7854895235-4517625475-503
S-1-5-21-5846521589-7854895235-4517625475-501
S-1-5-21-5846521589-7854895235-4517625475-1002
S-1-5-21-5846521589-7854895235-4517625475-504
^D
```

## Screenshots

![SIDAnalyzer demo](https://mauricelambert.github.io/info/python/security/SIDAnalyzer.png "SIDAnalyzer demo")

## Links

 - [Github Page](https://github.com/mauricelambert/SIDAnalyzer/)
 - [Executable](https://mauricelambert.github.io/info/python/security/SIDAnalyzer.pyz)
 - [Pypi package](https://pypi.org/project/SIDAnalyzer/)

## Licence

Licensed under the [GPL, version 3](https://www.gnu.org/licenses/).
